# Go API client for mlbstats

Official API for Major League Baseball.

## Overview
This API client was generated by the [swagger-codegen](https://github.com/swagger-api/swagger-codegen) project.  By using the [swagger-spec](https://github.com/swagger-api/swagger-spec) from a remote server, you can easily generate an API client.

- API version: 2.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.go.GoClientCodegen

## Installation
Put the package under your project folder and add the following in import:
```golang
import "./mlbstats"
```

## Documentation for API Endpoints

All URIs are relative to *https://statsapi.mlb.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnalyticsApi* | [**ContextMetrics**](docs/AnalyticsApi.md#contextmetrics) | **Get** /api/v1/game/{gamePk}/{guid}/contextMetrics | Get context metrics for a specific gamePk.
*AnalyticsApi* | [**ContextMetricsWithAverages**](docs/AnalyticsApi.md#contextmetricswithaverages) | **Get** /api/v1/game/{gamePk}/{guid}/contextMetricsAverages | Get a json file containing raw coordinate data and refined calculated metrics.
*AnalyticsApi* | [**ContextMetricsWithAveragesPost**](docs/AnalyticsApi.md#contextmetricswithaveragespost) | **Post** /api/v1/game/{gamePk}/{guid}/contextMetricsAverages | Get a json file containing raw coordinate data and refined calculated metrics.
*AnalyticsApi* | [**GameGuids**](docs/AnalyticsApi.md#gameguids) | **Get** /api/v1/game/{gamePk}/guids | Get the GUIDs (plays) for a specific game. 
*AnalyticsApi* | [**GameGuidsFromPostgresRange**](docs/AnalyticsApi.md#gameguidsfrompostgresrange) | **Get** /api/v1/analytics/guids | Get the GUIDs (plays) for a specific game. 
*AnalyticsApi* | [**GameGuidsFromPostgresRangeByGame**](docs/AnalyticsApi.md#gameguidsfrompostgresrangebygame) | **Get** /api/v1/analytics/game | Get all games by updated date.
*AnalyticsApi* | [**GameLastPitch**](docs/AnalyticsApi.md#gamelastpitch) | **Get** /api/v1/game/lastPitch | Get the last pitch for a list of games
*AnalyticsApi* | [**HomeRunBallparks**](docs/AnalyticsApi.md#homerunballparks) | **Get** /api/v1/game/{gamePk}/{guid}/homeRunBallparks | Get if the play is a home run is each park for a specific play.
*AnalyticsApi* | [**ParsedJsonFormattedAnalytics**](docs/AnalyticsApi.md#parsedjsonformattedanalytics) | **Get** /api/v1/game/{gamePk}/{guid}/analytics | Get Statcast data for a specific play.
*AttendanceApi* | [**GetTeamAttendance**](docs/AttendanceApi.md#getteamattendance) | **Get** /api/v1/attendance | Get team attendance
*AwardsApi* | [**AwardRecipients**](docs/AwardsApi.md#awardrecipients) | **Get** /api/v1/awards/{awardId}/recipients | View recipients of an award
*AwardsApi* | [**Awards**](docs/AwardsApi.md#awards) | **Get** /api/v1/awards | View awards info
*AwardsApi* | [**Awards1**](docs/AwardsApi.md#awards1) | **Get** /api/v1/awards/{awardId} | View awards info
*BatTrackingApi* | [**BatTracking**](docs/BatTrackingApi.md#battracking) | **Get** /api/v1/batTracking/game/{gamePk}/{playId} | View Bat Tracking Data by playId and gameId
*BiomechanicsApi* | [**Biomechanical**](docs/BiomechanicsApi.md#biomechanical) | **Get** /api/v1/game/{gamePk}/{playId}/analytics/biomechanics/{positionId} | View Biomechanical data by playId and gameId filtered by player positionId
*BroadcastApi* | [**GetAllBroadcasters**](docs/BroadcastApi.md#getallbroadcasters) | **Get** /api/v1/broadcasters | Get All Active Broadcasters
*BroadcastApi* | [**GetBroadcasts**](docs/BroadcastApi.md#getbroadcasts) | **Get** /api/v1/broadcast | Get Broadcasters
*ConferenceApi* | [**Conferences**](docs/ConferenceApi.md#conferences) | **Get** /api/v1/conferences | View conference info
*ConferenceApi* | [**Conferences1**](docs/ConferenceApi.md#conferences1) | **Get** /api/v1/conferences/{conferenceId} | View conference info
*DivisionApi* | [**Divisions**](docs/DivisionApi.md#divisions) | **Get** /api/v1/divisions | Get division information
*DivisionApi* | [**Divisions1**](docs/DivisionApi.md#divisions1) | **Get** /api/v1/divisions/{divisionId} | Get division information
*DraftApi* | [**DraftPicks**](docs/DraftApi.md#draftpicks) | **Get** /api/v1/draft | View MLB Drafted Players
*DraftApi* | [**DraftPicks1**](docs/DraftApi.md#draftpicks1) | **Get** /api/v1/draft/{year} | View MLB Drafted Players
*DraftApi* | [**DraftProspects**](docs/DraftApi.md#draftprospects) | **Get** /api/v1/draft/prospects | View MLB Draft Prospects
*DraftApi* | [**DraftProspects1**](docs/DraftApi.md#draftprospects1) | **Get** /api/v1/draft/prospects/{year} | View MLB Draft Prospects
*DraftApi* | [**LatestDraftPicks**](docs/DraftApi.md#latestdraftpicks) | **Get** /api/v1/draft/{year}/latest | Get the last drafted player and the next 5 teams up to pick
*GameApi* | [**Boxscore**](docs/GameApi.md#boxscore) | **Get** /api/v1/game/{game_pk}/boxscore | Get game boxscore.
*GameApi* | [**ColorFeed**](docs/GameApi.md#colorfeed) | **Get** /api/v1/game/{game_pk}/feed/color | Get game color feed.
*GameApi* | [**ColorTimestamps**](docs/GameApi.md#colortimestamps) | **Get** /api/v1/game/{game_pk}/feed/color/timestamps | Retrieve all of the color timestamps for a game.
*GameApi* | [**Content**](docs/GameApi.md#content) | **Get** /api/v1/game/{game_pk}/content | Retrieve all content for a game.
*GameApi* | [**CurrentGameStats1**](docs/GameApi.md#currentgamestats1) | **Get** /api/v1/game/changes | View a game change log
*GameApi* | [**GetGameContextMetrics**](docs/GameApi.md#getgamecontextmetrics) | **Get** /api/v1/game/{gamePk}/contextMetrics | Get the context metrics for this game based on its current state
*GameApi* | [**GetGameWithMetrics**](docs/GameApi.md#getgamewithmetrics) | **Get** /api/v1/game/{gamePk}/withMetrics | Get game info with metrics
*GameApi* | [**GetWinProbability**](docs/GameApi.md#getwinprobability) | **Get** /api/v1/game/{gamePk}/winProbability | Get the win probability for this game
*GameApi* | [**Linescore**](docs/GameApi.md#linescore) | **Get** /api/v1/game/{game_pk}/linescore | Get game linescore
*GameApi* | [**LiveGameDiffPatchV1**](docs/GameApi.md#livegamediffpatchv1) | **Get** /api/v1.1/game/{game_pk}/feed/live/diffPatch | Get live game status diffPatch.
*GameApi* | [**LiveGameV1**](docs/GameApi.md#livegamev1) | **Get** /api/v1.1/game/{game_pk}/feed/live | Get live game status.
*GameApi* | [**LiveTimestampv11**](docs/GameApi.md#livetimestampv11) | **Get** /api/v1.1/game/{game_pk}/feed/live/timestamps | Retrieve all of the play timestamps for a game.
*GameApi* | [**PlayByPlay**](docs/GameApi.md#playbyplay) | **Get** /api/v1/game/{game_pk}/playByPlay | Get game play By Play
*GamePaceApi* | [**GamePace**](docs/GamePaceApi.md#gamepace) | **Get** /api/v1/gamePace | View time of game info
*HighLowApi* | [**HighLow**](docs/HighLowApi.md#highlow) | **Get** /api/v1/highLow/{highLowType} | View high/low stats by player or team
*HighLowApi* | [**HighLowStats**](docs/HighLowApi.md#highlowstats) | **Get** /api/v1/highLow/types | View high/low stat types
*HomerunDerbyApi* | [**HomeRunDerbyBracket**](docs/HomerunDerbyApi.md#homerunderbybracket) | **Get** /api/v1/homeRunDerby/{gamePk} | View a home run derby object
*HomerunDerbyApi* | [**HomeRunDerbyBracket1**](docs/HomerunDerbyApi.md#homerunderbybracket1) | **Get** /api/v1/homeRunDerby | View a home run derby object
*HomerunDerbyApi* | [**HomeRunDerbyBracket2**](docs/HomerunDerbyApi.md#homerunderbybracket2) | **Get** /api/v1/homeRunDerby/{gamePk}/bracket | View a home run derby object
*HomerunDerbyApi* | [**HomeRunDerbyBracket3**](docs/HomerunDerbyApi.md#homerunderbybracket3) | **Get** /api/v1/homeRunDerby/bracket | View a home run derby object
*HomerunDerbyApi* | [**HomeRunDerbyMixedMode**](docs/HomerunDerbyApi.md#homerunderbymixedmode) | **Get** /api/v1/homeRunDerby/{gamePk}/mixed | View home run derby mixed mode (Bracket/Pool combo)
*HomerunDerbyApi* | [**HomeRunDerbyMixedMode1**](docs/HomerunDerbyApi.md#homerunderbymixedmode1) | **Get** /api/v1/homeRunDerby/mixed | View home run derby mixed mode (Bracket/Pool combo)
*HomerunDerbyApi* | [**HomeRunDerbyPool**](docs/HomerunDerbyApi.md#homerunderbypool) | **Get** /api/v1/homeRunDerby/{gamePk}/pool | View home run derby pool
*HomerunDerbyApi* | [**HomeRunDerbyPool1**](docs/HomerunDerbyApi.md#homerunderbypool1) | **Get** /api/v1/homeRunDerby/pool | View home run derby pool
*JobApi* | [**Datacasters**](docs/JobApi.md#datacasters) | **Get** /api/v1/jobs/datacasters | Get datacaster jobs
*JobApi* | [**GetJobsByType**](docs/JobApi.md#getjobsbytype) | **Get** /api/v1/jobs | Get jobs by type
*JobApi* | [**OfficialScorers**](docs/JobApi.md#officialscorers) | **Get** /api/v1/jobs/officialScorers | Get official scorers
*JobApi* | [**UmpireSchedule**](docs/JobApi.md#umpireschedule) | **Get** /api/v1/jobs/umpires/games/{umpireId} | Get umpires and associated game for umpireId
*JobApi* | [**Umpires**](docs/JobApi.md#umpires) | **Get** /api/v1/jobs/umpires | Get umpires
*LeagueApi* | [**AllStarBallot**](docs/LeagueApi.md#allstarballot) | **Get** /api/v1/league/allStarBallot | View al star ballot info
*LeagueApi* | [**AllStarBallot1**](docs/LeagueApi.md#allstarballot1) | **Get** /api/v1/league/{leagueId}/allStarBallot | View al star ballot info
*LeagueApi* | [**AllStarBallot2**](docs/LeagueApi.md#allstarballot2) | **Get** /api/v1/leagues/allStarBallot | View al star ballot info
*LeagueApi* | [**AllStarBallot3**](docs/LeagueApi.md#allstarballot3) | **Get** /api/v1/leagues/{leagueId}/allStarBallot | View al star ballot info
*LeagueApi* | [**AllStarFinalVote**](docs/LeagueApi.md#allstarfinalvote) | **Get** /api/v1/league/{leagueId}/allStarFinalVote | View all star final vote info
*LeagueApi* | [**AllStarFinalVote1**](docs/LeagueApi.md#allstarfinalvote1) | **Get** /api/v1/leagues/{leagueId}/allStarFinalVote | View all star final vote info
*LeagueApi* | [**AllStarWriteIns**](docs/LeagueApi.md#allstarwriteins) | **Get** /api/v1/league/{leagueId}/allStarWriteIns | View all star write ins info
*LeagueApi* | [**AllStarWriteIns1**](docs/LeagueApi.md#allstarwriteins1) | **Get** /api/v1/leagues/{leagueId}/allStarWriteIns | View all star write ins info
*LeagueApi* | [**League**](docs/LeagueApi.md#league) | **Get** /api/v1/league | View league info
*LeagueApi* | [**League1**](docs/LeagueApi.md#league1) | **Get** /api/v1/league/{leagueId} | View league info
*LeagueApi* | [**League2**](docs/LeagueApi.md#league2) | **Get** /api/v1/leagues | View league info
*LeagueApi* | [**League3**](docs/LeagueApi.md#league3) | **Get** /api/v1/leagues/{leagueId} | View league info
*MilestonesApi* | [**AchievementStatuses**](docs/MilestonesApi.md#achievementstatuses) | **Get** /api/v1/achievementStatuses | View available achievementStatus options
*MilestonesApi* | [**MilestoneDurations**](docs/MilestonesApi.md#milestonedurations) | **Get** /api/v1/milestoneDurations | View available milestoneDurations options
*MilestonesApi* | [**MilestoneLookups**](docs/MilestonesApi.md#milestonelookups) | **Get** /api/v1/milestoneLookups | View available milestoneLookup options
*MilestonesApi* | [**MilestoneStatistics**](docs/MilestonesApi.md#milestonestatistics) | **Get** /api/v1/milestoneStatistics | View available milestone statistics options
*MilestonesApi* | [**MilestoneTypes**](docs/MilestonesApi.md#milestonetypes) | **Get** /api/v1/milestoneTypes | View available milestoneType options
*MilestonesApi* | [**Milestones**](docs/MilestonesApi.md#milestones) | **Get** /api/v1/milestones | View pending and achieved milestones.
*MiscApi* | [**AggregateSortEnum**](docs/MiscApi.md#aggregatesortenum) | **Get** /api/v1/sortModifiers | List all stat fields
*MiscApi* | [**BaseballStats**](docs/MiscApi.md#baseballstats) | **Get** /api/v1/baseballStats | List all baseball stats
*MiscApi* | [**BroadcastAvailabilityTypes**](docs/MiscApi.md#broadcastavailabilitytypes) | **Get** /api/v1/broadcastAvailability | View broadcast availability options
*MiscApi* | [**CoachingVideoTypes**](docs/MiscApi.md#coachingvideotypes) | **Get** /api/v1/coachingVideoTypes | List all coaching video types
*MiscApi* | [**EventStatus**](docs/MiscApi.md#eventstatus) | **Get** /api/v1/eventStatus | List all possible event status types
*MiscApi* | [**EventTypes**](docs/MiscApi.md#eventtypes) | **Get** /api/v1/eventTypes | List all event types
*MiscApi* | [**FielderDetailTypes**](docs/MiscApi.md#fielderdetailtypes) | **Get** /api/v1/fielderDetailTypes | List fielder detail types
*MiscApi* | [**FreeGameTypes**](docs/MiscApi.md#freegametypes) | **Get** /api/v1/freeGameTypes | View free game types
*MiscApi* | [**GameStatus**](docs/MiscApi.md#gamestatus) | **Get** /api/v1/gameStatus | List all status types
*MiscApi* | [**GameTypes**](docs/MiscApi.md#gametypes) | **Get** /api/v1/gameTypes | List all game types
*MiscApi* | [**GamedayTypes**](docs/MiscApi.md#gamedaytypes) | **Get** /api/v1/gamedayTypes | List all gameday types
*MiscApi* | [**GetLookupValues**](docs/MiscApi.md#getlookupvalues) | **Get** /api/v1/lookup/values/all | View all lookup values
*MiscApi* | [**GroupByTypes**](docs/MiscApi.md#groupbytypes) | **Get** /api/v1/groupByTypes | List groupBy types
*MiscApi* | [**HitTrajectories**](docs/MiscApi.md#hittrajectories) | **Get** /api/v1/hitTrajectories | List all hit trajectories
*MiscApi* | [**JobTypes**](docs/MiscApi.md#jobtypes) | **Get** /api/v1/jobTypes | List all job types
*MiscApi* | [**Languages**](docs/MiscApi.md#languages) | **Get** /api/v1/languages | List all support languages
*MiscApi* | [**LeagueLeaderTypes**](docs/MiscApi.md#leagueleadertypes) | **Get** /api/v1/leagueLeaderTypes | List all possible player league leader types
*MiscApi* | [**LogicalEvents**](docs/MiscApi.md#logicalevents) | **Get** /api/v1/logicalEvents | List all logical event types
*MiscApi* | [**MediaStateTypes**](docs/MiscApi.md#mediastatetypes) | **Get** /api/v1/mediaState | View media state options
*MiscApi* | [**Metrics**](docs/MiscApi.md#metrics) | **Get** /api/v1/metrics | List all possible metrics
*MiscApi* | [**MoundVisitTypes**](docs/MiscApi.md#moundvisittypes) | **Get** /api/v1/moundVisitTypes | List all mound visit types
*MiscApi* | [**PerformerTypes**](docs/MiscApi.md#performertypes) | **Get** /api/v1/performerTypes | List all possible performer types
*MiscApi* | [**PitchCodes**](docs/MiscApi.md#pitchcodes) | **Get** /api/v1/pitchCodes | List all pitch codes
*MiscApi* | [**PitchTypes**](docs/MiscApi.md#pitchtypes) | **Get** /api/v1/pitchTypes | List all pitch classification types
*MiscApi* | [**Platforms**](docs/MiscApi.md#platforms) | **Get** /api/v1/platforms | List all possible platforms
*MiscApi* | [**PlayerStatusCodes**](docs/MiscApi.md#playerstatuscodes) | **Get** /api/v1/playerStatusCodes | List all player status codes
*MiscApi* | [**Positions**](docs/MiscApi.md#positions) | **Get** /api/v1/positions | List all possible positions
*MiscApi* | [**ReviewReasons**](docs/MiscApi.md#reviewreasons) | **Get** /api/v1/reviewReasons | List all replay review reasons
*MiscApi* | [**RoofTypes**](docs/MiscApi.md#rooftypes) | **Get** /api/v1/roofTypes | List all roof types
*MiscApi* | [**RosterTypes**](docs/MiscApi.md#rostertypes) | **Get** /api/v1/rosterTypes | List all possible roster types
*MiscApi* | [**RuleSettings**](docs/MiscApi.md#rulesettings) | **Get** /api/v1/ruleSettings | List all ruleSettings
*MiscApi* | [**RunnerDetailTypes**](docs/MiscApi.md#runnerdetailtypes) | **Get** /api/v1/runnerDetailTypes | List runner detail types
*MiscApi* | [**ScheduleEventTypes**](docs/MiscApi.md#scheduleeventtypes) | **Get** /api/v1/scheduleEventTypes | List all schedule event types
*MiscApi* | [**ScheduleTypes**](docs/MiscApi.md#scheduletypes) | **Get** /api/v1/scheduleTypes | List all possible schedule types
*MiscApi* | [**SitCodes**](docs/MiscApi.md#sitcodes) | **Get** /api/v1/situationCodes | List all situation codes
*MiscApi* | [**Sky**](docs/MiscApi.md#sky) | **Get** /api/v1/sky | List all sky options
*MiscApi* | [**StandingsTypes**](docs/MiscApi.md#standingstypes) | **Get** /api/v1/standingsTypes | List all standings types
*MiscApi* | [**StatFields**](docs/MiscApi.md#statfields) | **Get** /api/v1/statFields | List all stat fields
*MiscApi* | [**StatGroups**](docs/MiscApi.md#statgroups) | **Get** /api/v1/statGroups | List all stat groups
*MiscApi* | [**StatSearchConfig**](docs/MiscApi.md#statsearchconfig) | **Get** /api/v1/stats/search/config | Stats Search Config Endpoint
*MiscApi* | [**StatSearchGroupByTypes**](docs/MiscApi.md#statsearchgroupbytypes) | **Get** /api/v1/stats/search/groupByTypes | List groupBy types
*MiscApi* | [**StatSearchParams**](docs/MiscApi.md#statsearchparams) | **Get** /api/v1/stats/search/params | List stat search parameters
*MiscApi* | [**StatSearchStats**](docs/MiscApi.md#statsearchstats) | **Get** /api/v1/stats/search/stats | List stat search stats
*MiscApi* | [**StatTypes**](docs/MiscApi.md#stattypes) | **Get** /api/v1/statTypes | List all stat types
*MiscApi* | [**StatcastPositionTypes**](docs/MiscApi.md#statcastpositiontypes) | **Get** /api/v1/statcastPositionTypes | List all statcast position types
*MiscApi* | [**TrackingSoftwareVersions**](docs/MiscApi.md#trackingsoftwareversions) | **Get** /api/v1/trackingSoftwareVersions | List the tracking software versions and notes
*MiscApi* | [**TrackingSystemOwners**](docs/MiscApi.md#trackingsystemowners) | **Get** /api/v1/trackingSystemOwners | List all tracking system owners
*MiscApi* | [**TrackingVendors**](docs/MiscApi.md#trackingvendors) | **Get** /api/v1/trackingVendors | List all tracking vendors
*MiscApi* | [**TrackingVersions**](docs/MiscApi.md#trackingversions) | **Get** /api/v1/trackingVersions | List all tracking versions
*MiscApi* | [**TransactionTypes**](docs/MiscApi.md#transactiontypes) | **Get** /api/v1/transactionTypes | List all transaction types
*MiscApi* | [**UpdateGameStatuses**](docs/MiscApi.md#updategamestatuses) | **Post** /api/v1/gameStatus | Clear all status types
*MiscApi* | [**UpdateJobTypes**](docs/MiscApi.md#updatejobtypes) | **Post** /api/v1/jobTypes | 
*MiscApi* | [**VideoResolutionTypes**](docs/MiscApi.md#videoresolutiontypes) | **Get** /api/v1/videoResolutionTypes | View video resolution options
*MiscApi* | [**ViolationTypes**](docs/MiscApi.md#violationtypes) | **Get** /api/v1/violationTypes | View available violationType options
*MiscApi* | [**WeatherTrajectoryConfidences**](docs/MiscApi.md#weathertrajectoryconfidences) | **Get** /api/v1/weatherTrajectoryConfidences | List all weather trajectories
*MiscApi* | [**WindDirection**](docs/MiscApi.md#winddirection) | **Get** /api/v1/windDirection | List all wind direction options
*PersonApi* | [**Award**](docs/PersonApi.md#award) | **Get** /api/v1/people/{personId}/awards | View a player&#x27;s awards
*PersonApi* | [**CurrentGameStats**](docs/PersonApi.md#currentgamestats) | **Get** /api/v1/people/changes | View a player&#x27;s change log
*PersonApi* | [**FreeAgents**](docs/PersonApi.md#freeagents) | **Get** /api/v1/people/freeAgents | Get free agents
*PersonApi* | [**Person**](docs/PersonApi.md#person) | **Get** /api/v1/people/{personId} | View a player
*PersonApi* | [**Person1**](docs/PersonApi.md#person1) | **Get** /api/v1/people | View a player
*PersonApi* | [**PlayerGameStats**](docs/PersonApi.md#playergamestats) | **Get** /api/v1/people/{personId}/stats/game/{gamePk} | View a player&#x27;s game stats
*PersonApi* | [**Search**](docs/PersonApi.md#search) | **Get** /api/v1/people/search | Search for a player by name
*PersonApi* | [**Stats3**](docs/PersonApi.md#stats3) | **Get** /api/v1/people/{personId}/stats | View a players stats
*PersonApi* | [**StatsMetrics**](docs/PersonApi.md#statsmetrics) | **Get** /api/v1/people/{personId}/stats/metrics | View a player&#x27;s stat metrics
*PredictionsApi* | [**GetProps**](docs/PredictionsApi.md#getprops) | **Get** /api/v1/props/play/predictions | Get play-level predictions based on input scenarios
*PredictionsApi* | [**GetPropsAdjust**](docs/PredictionsApi.md#getpropsadjust) | **Get** /api/v1/props/play/predictions/adjust | Get play-level predictions based on input scenarios
*ReviewsApi* | [**GetReviewInfo**](docs/ReviewsApi.md#getreviewinfo) | **Get** /api/v1/review | Get review info
*ScheduleApi* | [**PostseasonSchedule**](docs/ScheduleApi.md#postseasonschedule) | **Get** /api/v1/schedule/postseason | Get postseason schedule
*ScheduleApi* | [**PostseasonScheduleSeries**](docs/ScheduleApi.md#postseasonscheduleseries) | **Get** /api/v1/schedule/postseason/series | Get postseason series schedules
*ScheduleApi* | [**Schedule**](docs/ScheduleApi.md#schedule) | **Get** /api/v1/schedule | View schedule info based on scheduleType.
*ScheduleApi* | [**Schedule1**](docs/ScheduleApi.md#schedule1) | **Get** /api/v1/schedule/{scheduleType} | View schedule info based on scheduleType.
*ScheduleApi* | [**TieGames**](docs/ScheduleApi.md#tiegames) | **Get** /api/v1/schedule/games/tied | Get tied game schedules
*ScheduleApi* | [**TrackingEventsSchedule**](docs/ScheduleApi.md#trackingeventsschedule) | **Get** /api/v1/schedule/trackingEvents | Get tracking event schedules
*ScheduleApi* | [**TuneIn**](docs/ScheduleApi.md#tunein) | **Get** /api/v1/schedule/postseason/tuneIn | Get postseason TuneIn schedules
*SeasonApi* | [**AllSeasons**](docs/SeasonApi.md#allseasons) | **Get** /api/v1/seasons/all | View all seasons
*SeasonApi* | [**Seasons**](docs/SeasonApi.md#seasons) | **Get** /api/v1/seasons | View season info
*SeasonApi* | [**Seasons1**](docs/SeasonApi.md#seasons1) | **Get** /api/v1/seasons/{seasonId} | View season info
*SkeletalApi* | [**SkeletalChunked**](docs/SkeletalApi.md#skeletalchunked) | **Get** /api/v1/game/{gamePk}/{playId}/analytics/skeletalData/chunked | View Skeletal Data by playId and gameId chunked
*SkeletalApi* | [**SkeletalDataFileNames**](docs/SkeletalApi.md#skeletaldatafilenames) | **Get** /api/v1/game/{gamePk}/{playId}/analytics/skeletalData/files | View Skeletal Data by playId and gameId files
*SportsApi* | [**AllSportBallot**](docs/SportsApi.md#allsportballot) | **Get** /api/v1/sports/{sportId}/allSportBallot | Get ALL MLB ballot for sport
*SportsApi* | [**SportPlayers**](docs/SportsApi.md#sportplayers) | **Get** /api/v1/sports/{sportId}/players | Get all players for a sport level
*SportsApi* | [**Sports**](docs/SportsApi.md#sports) | **Get** /api/v1/sports | Get sports information
*SportsApi* | [**Sports1**](docs/SportsApi.md#sports1) | **Get** /api/v1/sports/{sportId} | Get sports information
*StandingsApi* | [**Standings**](docs/StandingsApi.md#standings) | **Get** /api/v1/standings/{standingsType} | View standings for a league
*StandingsApi* | [**Standings1**](docs/StandingsApi.md#standings1) | **Get** /api/v1/standings | View standings for a league
*StatsApi* | [**BeastStats**](docs/StatsApi.md#beaststats) | **Get** /api/v1/stats/search | View stats from search
*StatsApi* | [**GetOutsAboveAverage**](docs/StatsApi.md#getoutsaboveaverage) | **Get** /api/v1/stats/analytics/outsAboveAverage | Get outs above average for the current batter
*StatsApi* | [**GetSprayChart**](docs/StatsApi.md#getspraychart) | **Get** /api/v1/stats/analytics/sprayChart | Get the spray chart info for the current batter
*StatsApi* | [**GetStolenBaseProbability**](docs/StatsApi.md#getstolenbaseprobability) | **Get** /api/v1/stats/analytics/stolenBaseProbability | Get the probability of a hit for the given hit data
*StatsApi* | [**GroupedStats**](docs/StatsApi.md#groupedstats) | **Get** /api/v1/stats/grouped | View grouped stats
*StatsApi* | [**Leaders2**](docs/StatsApi.md#leaders2) | **Get** /api/v1/stats/leaders | Get leaders for a statistic
*StatsApi* | [**MetricStats**](docs/StatsApi.md#metricstats) | **Get** /api/v1/stats/metrics | View metric stats
*StatsApi* | [**Stats2**](docs/StatsApi.md#stats2) | **Get** /api/v1/stats | View stats
*StreaksApi* | [**GetStreaks**](docs/StreaksApi.md#getstreaks) | **Get** /api/v1/streaks | View streaks
*StreaksApi* | [**StreakTypes**](docs/StreaksApi.md#streaktypes) | **Get** /api/v1/streaks/types | View streaks parameter options
*TeamsApi* | [**Affiliates**](docs/TeamsApi.md#affiliates) | **Get** /api/v1/teams/{teamId}/affiliates | View team and affiliate teams
*TeamsApi* | [**Affiliates1**](docs/TeamsApi.md#affiliates1) | **Get** /api/v1/teams/affiliates | View team and affiliate teams
*TeamsApi* | [**AllTeams**](docs/TeamsApi.md#allteams) | **Get** /api/v1/teams/{teamId}/history | View historical records for a list of teams
*TeamsApi* | [**AllTeams1**](docs/TeamsApi.md#allteams1) | **Get** /api/v1/teams/history | View historical records for a list of teams
*TeamsApi* | [**Alumni**](docs/TeamsApi.md#alumni) | **Get** /api/v1/teams/{teamId}/alumni | View all team alumni
*TeamsApi* | [**Coaches**](docs/TeamsApi.md#coaches) | **Get** /api/v1/teams/{teamId}/coaches | View all coaches for a team
*TeamsApi* | [**Leaders**](docs/TeamsApi.md#leaders) | **Get** /api/v1/teams/{teamId}/leaders | View team stat leaders
*TeamsApi* | [**Leaders1**](docs/TeamsApi.md#leaders1) | **Get** /api/v1/teams/stats/leaders | View leaders for team stats
*TeamsApi* | [**Personnel**](docs/TeamsApi.md#personnel) | **Get** /api/v1/teams/{teamId}/personnel | View all coaches for a team
*TeamsApi* | [**Roster**](docs/TeamsApi.md#roster) | **Get** /api/v1/teams/{teamId}/roster | View a teams roster
*TeamsApi* | [**Roster1**](docs/TeamsApi.md#roster1) | **Get** /api/v1/teams/{teamId}/roster/{rosterType} | View a teams roster
*TeamsApi* | [**Stats**](docs/TeamsApi.md#stats) | **Get** /api/v1/teams/{teamId}/stats | View a teams stats
*TeamsApi* | [**Stats1**](docs/TeamsApi.md#stats1) | **Get** /api/v1/teams/stats | View a teams stats
*TeamsApi* | [**Teams**](docs/TeamsApi.md#teams) | **Get** /api/v1/teams | View info for all teams
*TeamsApi* | [**Teams1**](docs/TeamsApi.md#teams1) | **Get** /api/v1/teams/{teamId} | View info for all teams
*TeamsApi* | [**UpdateAlumni**](docs/TeamsApi.md#updatealumni) | **Post** /api/v1/teams/{teamId}/alumni | 
*TransactionsApi* | [**Transactions**](docs/TransactionsApi.md#transactions) | **Get** /api/v1/transactions | View transaction info
*UniformsApi* | [**UniformsByGame**](docs/UniformsApi.md#uniformsbygame) | **Get** /api/v1/uniforms/game | View Game Uniform info
*UniformsApi* | [**UniformsByTeam**](docs/UniformsApi.md#uniformsbyteam) | **Get** /api/v1/uniforms/team | View Team Uniform info
*VenuesApi* | [**Venues**](docs/VenuesApi.md#venues) | **Get** /api/v1/venues | View venue info
*VenuesApi* | [**Venues1**](docs/VenuesApi.md#venues1) | **Get** /api/v1/venues/{venueId} | View venue info
*WeatherApi* | [**WeatherBasic**](docs/WeatherApi.md#weatherbasic) | **Get** /api/v1/weather/venues/{venueId}/basic | Get basic weather for a venue.
*WeatherApi* | [**WeatherDataBasedOnPlay**](docs/WeatherApi.md#weatherdatabasedonplay) | **Get** /api/v1/weather/game/{gamePk}/{playId} | Get the raw field weather data.
*WeatherApi* | [**WeatherForecast**](docs/WeatherApi.md#weatherforecast) | **Get** /api/v1/weather/game/{gamePk}/forecast/{roofType} | Get the weather forecast for a game.
*WeatherApi* | [**WeatherFull**](docs/WeatherApi.md#weatherfull) | **Get** /api/v1/weather/venues/{venueId}/full | Get full weather for a venue.

## Documentation For Models

 - [About](docs/About.md)
 - [AdditionalBio](docs/AdditionalBio.md)
 - [AdditionalBioRestObject](docs/AdditionalBioRestObject.md)
 - [AggregateSortTypeEnum](docs/AggregateSortTypeEnum.md)
 - [AggregateSortTypeRestObject](docs/AggregateSortTypeRestObject.md)
 - [AllStarEnum](docs/AllStarEnum.md)
 - [AnalyticsGameMetadataRestObject](docs/AnalyticsGameMetadataRestObject.md)
 - [AnalyticsGameMetadataWrapperRestObject](docs/AnalyticsGameMetadataWrapperRestObject.md)
 - [AnalyticsPlayMetadataRestObject](docs/AnalyticsPlayMetadataRestObject.md)
 - [AnalyticsPlayMetadataWrapperRestObject](docs/AnalyticsPlayMetadataWrapperRestObject.md)
 - [AnalyticsRestObject](docs/AnalyticsRestObject.md)
 - [ApplicationRestObject](docs/ApplicationRestObject.md)
 - [Article](docs/Article.md)
 - [AttendanceRecordRestObject](docs/AttendanceRecordRestObject.md)
 - [AttendanceRestObject](docs/AttendanceRestObject.md)
 - [Award](docs/Award.md)
 - [AwardRestObject](docs/AwardRestObject.md)
 - [AwardResult](docs/AwardResult.md)
 - [AwardResultRestObject](docs/AwardResultRestObject.md)
 - [AwardWinner](docs/AwardWinner.md)
 - [AwardWinnerRestObject](docs/AwardWinnerRestObject.md)
 - [AwardsRestObject](docs/AwardsRestObject.md)
 - [BallPositionDataRestObject](docs/BallPositionDataRestObject.md)
 - [BallPositionalDataRestObject](docs/BallPositionalDataRestObject.md)
 - [BaseballAbsChallenge](docs/BaseballAbsChallenge.md)
 - [BaseballAbsChallengeRestObject](docs/BaseballAbsChallengeRestObject.md)
 - [BaseballBoxscoreNoteRestObject](docs/BaseballBoxscoreNoteRestObject.md)
 - [BaseballBoxscoreNoteWrapRestObject](docs/BaseballBoxscoreNoteWrapRestObject.md)
 - [BaseballBoxscoreRestObject](docs/BaseballBoxscoreRestObject.md)
 - [BaseballChallenge](docs/BaseballChallenge.md)
 - [BaseballDecision](docs/BaseballDecision.md)
 - [BaseballDecisionRestObject](docs/BaseballDecisionRestObject.md)
 - [BaseballDefenseRestObject](docs/BaseballDefenseRestObject.md)
 - [BaseballDraftLatestRestObject](docs/BaseballDraftLatestRestObject.md)
 - [BaseballDraftListRestObject](docs/BaseballDraftListRestObject.md)
 - [BaseballDraftProspect](docs/BaseballDraftProspect.md)
 - [BaseballDraftProspectRestObject](docs/BaseballDraftProspectRestObject.md)
 - [BaseballDraftRestObject](docs/BaseballDraftRestObject.md)
 - [BaseballDraftRoundRestObject](docs/BaseballDraftRoundRestObject.md)
 - [BaseballGameAlert](docs/BaseballGameAlert.md)
 - [BaseballGameAlertRestObject](docs/BaseballGameAlertRestObject.md)
 - [BaseballGameContextRestObject](docs/BaseballGameContextRestObject.md)
 - [BaseballGameDataGameRestObject](docs/BaseballGameDataGameRestObject.md)
 - [BaseballGameDataRestObject](docs/BaseballGameDataRestObject.md)
 - [BaseballGameDateTimeRestObject](docs/BaseballGameDateTimeRestObject.md)
 - [BaseballGameFlag](docs/BaseballGameFlag.md)
 - [BaseballGameFlagRestObject](docs/BaseballGameFlagRestObject.md)
 - [BaseballGameLeaderRestObject](docs/BaseballGameLeaderRestObject.md)
 - [BaseballGameLeadersRestObject](docs/BaseballGameLeadersRestObject.md)
 - [BaseballGameLiveDataRestObject](docs/BaseballGameLiveDataRestObject.md)
 - [BaseballGameLiveLookinRestObject](docs/BaseballGameLiveLookinRestObject.md)
 - [BaseballGameMetaDataRestObject](docs/BaseballGameMetaDataRestObject.md)
 - [BaseballGameProbableRestObject](docs/BaseballGameProbableRestObject.md)
 - [BaseballGameRestObject](docs/BaseballGameRestObject.md)
 - [BaseballHit](docs/BaseballHit.md)
 - [BaseballHitDataRestObject](docs/BaseballHitDataRestObject.md)
 - [BaseballHotColdZone](docs/BaseballHotColdZone.md)
 - [BaseballHotColdZoneRestObject](docs/BaseballHotColdZoneRestObject.md)
 - [BaseballInning](docs/BaseballInning.md)
 - [BaseballLinescore](docs/BaseballLinescore.md)
 - [BaseballLinescoreRestObject](docs/BaseballLinescoreRestObject.md)
 - [BaseballLinescoreTeamInfoRestObject](docs/BaseballLinescoreTeamInfoRestObject.md)
 - [BaseballLineup](docs/BaseballLineup.md)
 - [BaseballLineupRestObject](docs/BaseballLineupRestObject.md)
 - [BaseballOffenseRestObject](docs/BaseballOffenseRestObject.md)
 - [BaseballPerson](docs/BaseballPerson.md)
 - [BaseballPersonRestObject](docs/BaseballPersonRestObject.md)
 - [BaseballPitch](docs/BaseballPitch.md)
 - [BaseballPitchDataRestObject](docs/BaseballPitchDataRestObject.md)
 - [BaseballPlay](docs/BaseballPlay.md)
 - [BaseballPlayByPlayRestObject](docs/BaseballPlayByPlayRestObject.md)
 - [BaseballPlayEvent](docs/BaseballPlayEvent.md)
 - [BaseballPlayEventRestObject](docs/BaseballPlayEventRestObject.md)
 - [BaseballPlayRestObject](docs/BaseballPlayRestObject.md)
 - [BaseballPlayerGameScoreRestObject](docs/BaseballPlayerGameScoreRestObject.md)
 - [BaseballPosition](docs/BaseballPosition.md)
 - [BaseballReview](docs/BaseballReview.md)
 - [BaseballReviewRestObject](docs/BaseballReviewRestObject.md)
 - [BaseballRoster](docs/BaseballRoster.md)
 - [BaseballRosterEntry](docs/BaseballRosterEntry.md)
 - [BaseballRosterEntryRestObject](docs/BaseballRosterEntryRestObject.md)
 - [BaseballRunnerMovement](docs/BaseballRunnerMovement.md)
 - [BaseballSchedule](docs/BaseballSchedule.md)
 - [BaseballScheduleItem](docs/BaseballScheduleItem.md)
 - [BaseballScheduleItemRestObject](docs/BaseballScheduleItemRestObject.md)
 - [BaseballScheduleItemTeamRestObject](docs/BaseballScheduleItemTeamRestObject.md)
 - [BaseballStats](docs/BaseballStats.md)
 - [BaseballStatsEnum](docs/BaseballStatsEnum.md)
 - [BaseballStatsTypeRestObject](docs/BaseballStatsTypeRestObject.md)
 - [BaseballTeam](docs/BaseballTeam.md)
 - [BaseballTeamBoxscore](docs/BaseballTeamBoxscore.md)
 - [BaseballTeamRestObject](docs/BaseballTeamRestObject.md)
 - [BaseballTeamReview](docs/BaseballTeamReview.md)
 - [BaseballTeamStandingsRecord](docs/BaseballTeamStandingsRecord.md)
 - [BaseballTeamUniformRestObject](docs/BaseballTeamUniformRestObject.md)
 - [BaseballTicket](docs/BaseballTicket.md)
 - [BaseballTicketRestObject](docs/BaseballTicketRestObject.md)
 - [BaseballViolation](docs/BaseballViolation.md)
 - [BasicWeatherWrapperRestObject](docs/BasicWeatherWrapperRestObject.md)
 - [BatImpactRestObject](docs/BatImpactRestObject.md)
 - [BatImpactSpeedRestObject](docs/BatImpactSpeedRestObject.md)
 - [BatImpactVelocityRestObject](docs/BatImpactVelocityRestObject.md)
 - [BatImpactVelocityRestObjectAfter](docs/BatImpactVelocityRestObjectAfter.md)
 - [BatImpactVelocityRestObjectBefore](docs/BatImpactVelocityRestObjectBefore.md)
 - [BatPositionRestObject](docs/BatPositionRestObject.md)
 - [BatSweetSpotRestObject](docs/BatSweetSpotRestObject.md)
 - [BatTrackingRestObject](docs/BatTrackingRestObject.md)
 - [BatTrackingSystemRestObject](docs/BatTrackingSystemRestObject.md)
 - [BatterDetailType](docs/BatterDetailType.md)
 - [BattingData](docs/BattingData.md)
 - [Breaks](docs/Breaks.md)
 - [BroadcastAvailability](docs/BroadcastAvailability.md)
 - [BroadcastAvailabilityRestObject](docs/BroadcastAvailabilityRestObject.md)
 - [Broadcaster](docs/Broadcaster.md)
 - [BroadcasterActiveStatusEnum](docs/BroadcasterActiveStatusEnum.md)
 - [BroadcasterRestObject](docs/BroadcasterRestObject.md)
 - [BroadcasterXrefId](docs/BroadcasterXrefId.md)
 - [CalculatedMetricContainerRestObject](docs/CalculatedMetricContainerRestObject.md)
 - [CalculatedMetricRestObject](docs/CalculatedMetricRestObject.md)
 - [CalendarTypes](docs/CalendarTypes.md)
 - [CalibrationContainerRestObject](docs/CalibrationContainerRestObject.md)
 - [CalibrationRestObject](docs/CalibrationRestObject.md)
 - [CalmDeviation](docs/CalmDeviation.md)
 - [Conference](docs/Conference.md)
 - [ConferenceRestObject](docs/ConferenceRestObject.md)
 - [ConferencesRestObject](docs/ConferencesRestObject.md)
 - [ContactPointPositionRestObject](docs/ContactPointPositionRestObject.md)
 - [ContentSummary](docs/ContentSummary.md)
 - [Coordinate](docs/Coordinate.md)
 - [CoordinateRestObject](docs/CoordinateRestObject.md)
 - [Coordinates](docs/Coordinates.md)
 - [CoordinatesRestObject](docs/CoordinatesRestObject.md)
 - [Count](docs/Count.md)
 - [DepthChart](docs/DepthChart.md)
 - [DepthChartRestObject](docs/DepthChartRestObject.md)
 - [Designation](docs/Designation.md)
 - [DesignationRestObject](docs/DesignationRestObject.md)
 - [Details](docs/Details.md)
 - [Division](docs/Division.md)
 - [DivisionRestObject](docs/DivisionRestObject.md)
 - [DivisionsRestObject](docs/DivisionsRestObject.md)
 - [DraftStatusEnum](docs/DraftStatusEnum.md)
 - [DraftTypeEnum](docs/DraftTypeEnum.md)
 - [DraftTypeEnumRestObject](docs/DraftTypeEnumRestObject.md)
 - [Duration](docs/Duration.md)
 - [DynamicEnumRestObject](docs/DynamicEnumRestObject.md)
 - [DynamicLookupEnum](docs/DynamicLookupEnum.md)
 - [Editorial](docs/Editorial.md)
 - [EducationInfo](docs/EducationInfo.md)
 - [EducationRestObject](docs/EducationRestObject.md)
 - [EventSequenceRestObject](docs/EventSequenceRestObject.md)
 - [EventStatus](docs/EventStatus.md)
 - [EventType](docs/EventType.md)
 - [ExpandEnum](docs/ExpandEnum.md)
 - [FeaturedMedia](docs/FeaturedMedia.md)
 - [FieldInfo](docs/FieldInfo.md)
 - [FieldInfoRestObject](docs/FieldInfoRestObject.md)
 - [FieldZoneRestObject](docs/FieldZoneRestObject.md)
 - [FieldZoneTypeRestObject](docs/FieldZoneTypeRestObject.md)
 - [FielderDetailType](docs/FielderDetailType.md)
 - [FieldingData](docs/FieldingData.md)
 - [FilterLevelEnum](docs/FilterLevelEnum.md)
 - [FilterLevelEnumRestObject](docs/FilterLevelEnumRestObject.md)
 - [FilterLevels](docs/FilterLevels.md)
 - [ForecastWeatherWrapperRestObject](docs/ForecastWeatherWrapperRestObject.md)
 - [FrameRestObject](docs/FrameRestObject.md)
 - [Franchise](docs/Franchise.md)
 - [FranchiseRestObject](docs/FranchiseRestObject.md)
 - [FreeAgentListRestObject](docs/FreeAgentListRestObject.md)
 - [FreeAgentRestObject](docs/FreeAgentRestObject.md)
 - [FreeGameType](docs/FreeGameType.md)
 - [FreeGameTypeEnum](docs/FreeGameTypeEnum.md)
 - [FreeGameTypeRestObject](docs/FreeGameTypeRestObject.md)
 - [FreeGameValueRestObject](docs/FreeGameValueRestObject.md)
 - [FullWeatherRestObject](docs/FullWeatherRestObject.md)
 - [FullWeatherWrapperRestObject](docs/FullWeatherWrapperRestObject.md)
 - [GameCms](docs/GameCms.md)
 - [GameContentRestObject](docs/GameContentRestObject.md)
 - [GameContentSummaryRestObject](docs/GameContentSummaryRestObject.md)
 - [GameDateBroadcast](docs/GameDateBroadcast.md)
 - [GameDateBroadcastRestObject](docs/GameDateBroadcastRestObject.md)
 - [GameEditorialRestObject](docs/GameEditorialRestObject.md)
 - [GameEventDetailTo](docs/GameEventDetailTo.md)
 - [GameHighlightsRestObject](docs/GameHighlightsRestObject.md)
 - [GameInfoRestObject](docs/GameInfoRestObject.md)
 - [GameMediaRestObject](docs/GameMediaRestObject.md)
 - [GameModeTo](docs/GameModeTo.md)
 - [GameNotes](docs/GameNotes.md)
 - [GameNotesRestObject](docs/GameNotesRestObject.md)
 - [GamePacePrPortalRestObject](docs/GamePacePrPortalRestObject.md)
 - [GamePaceRestObject](docs/GamePaceRestObject.md)
 - [GamePaceWrapperRestObject](docs/GamePaceWrapperRestObject.md)
 - [GameStatData](docs/GameStatData.md)
 - [GameStatusRestObject](docs/GameStatusRestObject.md)
 - [GameStory](docs/GameStory.md)
 - [GameStoryRestObject](docs/GameStoryRestObject.md)
 - [GameTo](docs/GameTo.md)
 - [GameTypeDates](docs/GameTypeDates.md)
 - [GameTypeDatesRestObject](docs/GameTypeDatesRestObject.md)
 - [GameTypeEnum](docs/GameTypeEnum.md)
 - [GeneralLookupRestObject](docs/GeneralLookupRestObject.md)
 - [GenericLookup](docs/GenericLookup.md)
 - [GroupByEnum](docs/GroupByEnum.md)
 - [GroupedStatData](docs/GroupedStatData.md)
 - [GroupedStatDataRestObject](docs/GroupedStatDataRestObject.md)
 - [HandlePositionRestObject](docs/HandlePositionRestObject.md)
 - [HeadPositionRestObject](docs/HeadPositionRestObject.md)
 - [HighLowContainerRestObject](docs/HighLowContainerRestObject.md)
 - [HighLowStatEnum](docs/HighLowStatEnum.md)
 - [HighLowTypeEnum](docs/HighLowTypeEnum.md)
 - [HighLowWrapperRestObject](docs/HighLowWrapperRestObject.md)
 - [Highlights](docs/Highlights.md)
 - [HitSegmentRestObject](docs/HitSegmentRestObject.md)
 - [HitTrajectory](docs/HitTrajectory.md)
 - [HitTrajectoryData](docs/HitTrajectoryData.md)
 - [HitTrajectoryDataRestObject](docs/HitTrajectoryDataRestObject.md)
 - [HomeRunDerbyBatterHitRestObject](docs/HomeRunDerbyBatterHitRestObject.md)
 - [HomeRunDerbyMatchupRestObject](docs/HomeRunDerbyMatchupRestObject.md)
 - [HomeRunDerbyRestObject](docs/HomeRunDerbyRestObject.md)
 - [HomeRunDerbyRoundBatterRestObject](docs/HomeRunDerbyRoundBatterRestObject.md)
 - [HomeRunDerbyRoundRestObject](docs/HomeRunDerbyRoundRestObject.md)
 - [HomeRunDerbyStatusRestObject](docs/HomeRunDerbyStatusRestObject.md)
 - [IFeed](docs/IFeed.md)
 - [IFeedRestObject](docs/IFeedRestObject.md)
 - [IGameStatus](docs/IGameStatus.md)
 - [IOfficialType](docs/IOfficialType.md)
 - [Image](docs/Image.md)
 - [ImageRestObject](docs/ImageRestObject.md)
 - [ImageTypeEnum](docs/ImageTypeEnum.md)
 - [IndoorDeviation](docs/IndoorDeviation.md)
 - [InningHit](docs/InningHit.md)
 - [InningHitWrap](docs/InningHitWrap.md)
 - [InningPlay](docs/InningPlay.md)
 - [InningRestObject](docs/InningRestObject.md)
 - [InningTeamInfoRestObject](docs/InningTeamInfoRestObject.md)
 - [JobTypeRestObject](docs/JobTypeRestObject.md)
 - [JsonNode](docs/JsonNode.md)
 - [LandingDataRestObject](docs/LandingDataRestObject.md)
 - [LandingPositionRestObject](docs/LandingPositionRestObject.md)
 - [Language](docs/Language.md)
 - [LaunchData](docs/LaunchData.md)
 - [LaunchDataRestObject](docs/LaunchDataRestObject.md)
 - [LeaderLimits](docs/LeaderLimits.md)
 - [Leaders](docs/Leaders.md)
 - [LeadersRestObject](docs/LeadersRestObject.md)
 - [League](docs/League.md)
 - [LeagueActiveStatusEnum](docs/LeagueActiveStatusEnum.md)
 - [LeagueLeaderContainerRestObject](docs/LeagueLeaderContainerRestObject.md)
 - [LeagueLeaderTypeRestObject](docs/LeagueLeaderTypeRestObject.md)
 - [LeagueListsEnum](docs/LeagueListsEnum.md)
 - [LeagueRestObject](docs/LeagueRestObject.md)
 - [LimitMetadata](docs/LimitMetadata.md)
 - [LimitMetadataRestObject](docs/LimitMetadataRestObject.md)
 - [Lineup](docs/Lineup.md)
 - [LiveLookin](docs/LiveLookin.md)
 - [LiveLookinPlayback](docs/LiveLookinPlayback.md)
 - [Location](docs/Location.md)
 - [LocationRestObject](docs/LocationRestObject.md)
 - [Matchup](docs/Matchup.md)
 - [MeasuredDataRestObject](docs/MeasuredDataRestObject.md)
 - [Media](docs/Media.md)
 - [MediaSourceType](docs/MediaSourceType.md)
 - [MediaState](docs/MediaState.md)
 - [MediaStateRestObject](docs/MediaStateRestObject.md)
 - [MetricType](docs/MetricType.md)
 - [MetricWarningRestObject](docs/MetricWarningRestObject.md)
 - [MilestoneAchievementStatusRestObject](docs/MilestoneAchievementStatusRestObject.md)
 - [MilestoneAchievementType](docs/MilestoneAchievementType.md)
 - [MilestoneContainerRestObject](docs/MilestoneContainerRestObject.md)
 - [MilestoneDuration](docs/MilestoneDuration.md)
 - [MilestoneDurationRestObject](docs/MilestoneDurationRestObject.md)
 - [MilestoneRestObject](docs/MilestoneRestObject.md)
 - [MilestoneRuleRestObject](docs/MilestoneRuleRestObject.md)
 - [MilestoneStatisticRestObject](docs/MilestoneStatisticRestObject.md)
 - [MilestoneType](docs/MilestoneType.md)
 - [MilestoneTypeRestObject](docs/MilestoneTypeRestObject.md)
 - [MoundVisitsRestObject](docs/MoundVisitsRestObject.md)
 - [Movement](docs/Movement.md)
 - [NonGameBroadcastRestObject](docs/NonGameBroadcastRestObject.md)
 - [NonGameDateBroadcast](docs/NonGameDateBroadcast.md)
 - [Official](docs/Official.md)
 - [OfficialRestObject](docs/OfficialRestObject.md)
 - [OrganizationType](docs/OrganizationType.md)
 - [OrganizationTypeRestObject](docs/OrganizationTypeRestObject.md)
 - [OtherNames](docs/OtherNames.md)
 - [OtherNamesRestObject](docs/OtherNamesRestObject.md)
 - [OtherTeamNames](docs/OtherTeamNames.md)
 - [PeopleRestObject](docs/PeopleRestObject.md)
 - [PerformerType](docs/PerformerType.md)
 - [PersonLeadersEnum](docs/PersonLeadersEnum.md)
 - [PersonStatGroupRestObject](docs/PersonStatGroupRestObject.md)
 - [Photo](docs/Photo.md)
 - [PhotoRestObject](docs/PhotoRestObject.md)
 - [PitchCode](docs/PitchCode.md)
 - [PitchCodeRestObject](docs/PitchCodeRestObject.md)
 - [PitchFxDataRestObject](docs/PitchFxDataRestObject.md)
 - [PitchHandTypeRestObject](docs/PitchHandTypeRestObject.md)
 - [PitchSegmentRestObject](docs/PitchSegmentRestObject.md)
 - [PitchTrajectoryDataRestObject](docs/PitchTrajectoryDataRestObject.md)
 - [PitchType](docs/PitchType.md)
 - [PitchTypeRestObject](docs/PitchTypeRestObject.md)
 - [PitcherDetailType](docs/PitcherDetailType.md)
 - [PitchingData](docs/PitchingData.md)
 - [Platform](docs/Platform.md)
 - [PlayCredit](docs/PlayCredit.md)
 - [PlayCreditRestObject](docs/PlayCreditRestObject.md)
 - [PlayEventRestObject](docs/PlayEventRestObject.md)
 - [PlayResultRestObject](docs/PlayResultRestObject.md)
 - [PlayWeatherWrapperRestObject](docs/PlayWeatherWrapperRestObject.md)
 - [PlayerActiveStatusEnum](docs/PlayerActiveStatusEnum.md)
 - [PlayerDraftInfo](docs/PlayerDraftInfo.md)
 - [PlayerDraftInfoRestObject](docs/PlayerDraftInfoRestObject.md)
 - [PlayerLeader](docs/PlayerLeader.md)
 - [PlayerLeaderRestObject](docs/PlayerLeaderRestObject.md)
 - [PlayerListPerson](docs/PlayerListPerson.md)
 - [PlayerPoolEnum](docs/PlayerPoolEnum.md)
 - [PlayerSequenceRestObject](docs/PlayerSequenceRestObject.md)
 - [Position](docs/Position.md)
 - [PositionRestObject](docs/PositionRestObject.md)
 - [PositionalMapRestObject](docs/PositionalMapRestObject.md)
 - [PostseasonScheduleRestObject](docs/PostseasonScheduleRestObject.md)
 - [PostseasonSeries](docs/PostseasonSeries.md)
 - [PostseasonSeriesRestObject](docs/PostseasonSeriesRestObject.md)
 - [Privilege](docs/Privilege.md)
 - [Promotion](docs/Promotion.md)
 - [PromotionRestObject](docs/PromotionRestObject.md)
 - [ProspectListRestObject](docs/ProspectListRestObject.md)
 - [PublicFacingEnum](docs/PublicFacingEnum.md)
 - [RelatedApplication](docs/RelatedApplication.md)
 - [Relative](docs/Relative.md)
 - [ReleaseDataRestObject](docs/ReleaseDataRestObject.md)
 - [RestObject](docs/RestObject.md)
 - [Result](docs/Result.md)
 - [ReviewDetails](docs/ReviewDetails.md)
 - [Role](docs/Role.md)
 - [RoofType](docs/RoofType.md)
 - [RoofTypeRestObject](docs/RoofTypeRestObject.md)
 - [RosterRestObject](docs/RosterRestObject.md)
 - [RosterType](docs/RosterType.md)
 - [RuleSettings](docs/RuleSettings.md)
 - [RuleSettingsOption](docs/RuleSettingsOption.md)
 - [RuleSettingsOptionRestObject](docs/RuleSettingsOptionRestObject.md)
 - [RuleSettingsRestObject](docs/RuleSettingsRestObject.md)
 - [RunnerDetailType](docs/RunnerDetailType.md)
 - [RunnerMovement](docs/RunnerMovement.md)
 - [RunnerSequenceRestObject](docs/RunnerSequenceRestObject.md)
 - [SacFlyProbability](docs/SacFlyProbability.md)
 - [ScheduleDateRestObject](docs/ScheduleDateRestObject.md)
 - [ScheduleEvent](docs/ScheduleEvent.md)
 - [ScheduleEventCms](docs/ScheduleEventCms.md)
 - [ScheduleEventRestObject](docs/ScheduleEventRestObject.md)
 - [ScheduleEventTypeRestObject](docs/ScheduleEventTypeRestObject.md)
 - [ScheduleEventTypes](docs/ScheduleEventTypes.md)
 - [ScheduleRestObject](docs/ScheduleRestObject.md)
 - [ScheduleSeriesRestObject](docs/ScheduleSeriesRestObject.md)
 - [ScheduleTypeEnum](docs/ScheduleTypeEnum.md)
 - [School](docs/School.md)
 - [SchoolRestObject](docs/SchoolRestObject.md)
 - [SeamOrientationRestObject](docs/SeamOrientationRestObject.md)
 - [Season](docs/Season.md)
 - [SeasonRestObject](docs/SeasonRestObject.md)
 - [SeasonsRestObject](docs/SeasonsRestObject.md)
 - [SegmentRestObject](docs/SegmentRestObject.md)
 - [SeriesStatus](docs/SeriesStatus.md)
 - [SeriesStatusRestObject](docs/SeriesStatusRestObject.md)
 - [SettingsRestObject](docs/SettingsRestObject.md)
 - [Site](docs/Site.md)
 - [SituationCodeRestObject](docs/SituationCodeRestObject.md)
 - [SkeletalDataRestObject](docs/SkeletalDataRestObject.md)
 - [SkeletalDataWrapperRestObject](docs/SkeletalDataWrapperRestObject.md)
 - [SkeletalFileData](docs/SkeletalFileData.md)
 - [SkeletonRestObject](docs/SkeletonRestObject.md)
 - [SocialMediaInfo](docs/SocialMediaInfo.md)
 - [SocialMediaRestObject](docs/SocialMediaRestObject.md)
 - [SortOrderEnum](docs/SortOrderEnum.md)
 - [Split](docs/Split.md)
 - [Sport](docs/Sport.md)
 - [SportActiveStatusEnum](docs/SportActiveStatusEnum.md)
 - [SportRestObject](docs/SportRestObject.md)
 - [SportTypeEnum](docs/SportTypeEnum.md)
 - [SportsRestObject](docs/SportsRestObject.md)
 - [StandingsOdds](docs/StandingsOdds.md)
 - [StandingsRestObject](docs/StandingsRestObject.md)
 - [StandingsType](docs/StandingsType.md)
 - [StartEndData](docs/StartEndData.md)
 - [StartEndDataRestObject](docs/StartEndDataRestObject.md)
 - [StatContainer](docs/StatContainer.md)
 - [StatContainerRestObject](docs/StatContainerRestObject.md)
 - [StatData](docs/StatData.md)
 - [StatDataRestObject](docs/StatDataRestObject.md)
 - [StatExemptionRestObject](docs/StatExemptionRestObject.md)
 - [StatField](docs/StatField.md)
 - [StatFields](docs/StatFields.md)
 - [StatGroup](docs/StatGroup.md)
 - [StatSearchConfigRestObject](docs/StatSearchConfigRestObject.md)
 - [StatSearchGroupByRestObject](docs/StatSearchGroupByRestObject.md)
 - [StatSearchParamRestObject](docs/StatSearchParamRestObject.md)
 - [StatSearchPersonFilterRestObject](docs/StatSearchPersonFilterRestObject.md)
 - [StatSearchSitCodeRestObject](docs/StatSearchSitCodeRestObject.md)
 - [StatSearchStatGroupRestObject](docs/StatSearchStatGroupRestObject.md)
 - [StatSearchStatRestObject](docs/StatSearchStatRestObject.md)
 - [StatSplits](docs/StatSplits.md)
 - [StatSplitsRestObject](docs/StatSplitsRestObject.md)
 - [StatType](docs/StatType.md)
 - [StatcastPositionRestObject](docs/StatcastPositionRestObject.md)
 - [Statistic](docs/Statistic.md)
 - [Stats](docs/Stats.md)
 - [StatsRestObject](docs/StatsRestObject.md)
 - [StatusFlags](docs/StatusFlags.md)
 - [StatusFlagsRestObject](docs/StatusFlagsRestObject.md)
 - [StreakLevelEnum](docs/StreakLevelEnum.md)
 - [StreakRestObject](docs/StreakRestObject.md)
 - [StreakSpanEnum](docs/StreakSpanEnum.md)
 - [StreakStatEnum](docs/StreakStatEnum.md)
 - [StreaksContainerRestObject](docs/StreaksContainerRestObject.md)
 - [StreaksWrapperRestObject](docs/StreaksWrapperRestObject.md)
 - [SystemRestObject](docs/SystemRestObject.md)
 - [TeamActiveStatusEnum](docs/TeamActiveStatusEnum.md)
 - [TeamContentCms](docs/TeamContentCms.md)
 - [TeamDesignationEnum](docs/TeamDesignationEnum.md)
 - [TeamInfo](docs/TeamInfo.md)
 - [TeamLeaderContainerRestObject](docs/TeamLeaderContainerRestObject.md)
 - [TeamPlayoffs](docs/TeamPlayoffs.md)
 - [TeamStandingsRecordContainerRestObject](docs/TeamStandingsRecordContainerRestObject.md)
 - [TeamStandingsRecordRestObject](docs/TeamStandingsRecordRestObject.md)
 - [TeamStatData](docs/TeamStatData.md)
 - [TeamsRestObject](docs/TeamsRestObject.md)
 - [TimeZone](docs/TimeZone.md)
 - [TimeZoneRestObject](docs/TimeZoneRestObject.md)
 - [TrackingSoftwareVersionRestObject](docs/TrackingSoftwareVersionRestObject.md)
 - [TrackingSystemOwner](docs/TrackingSystemOwner.md)
 - [TrackingVendor](docs/TrackingVendor.md)
 - [TrackingVendorVersionContainer](docs/TrackingVendorVersionContainer.md)
 - [TrackingVersion](docs/TrackingVersion.md)
 - [TrackingVersionRestObject](docs/TrackingVersionRestObject.md)
 - [Transaction](docs/Transaction.md)
 - [TransactionRestObject](docs/TransactionRestObject.md)
 - [TransactionsRestObject](docs/TransactionsRestObject.md)
 - [UniformAssetTypeRestObject](docs/UniformAssetTypeRestObject.md)
 - [UniformRestObject](docs/UniformRestObject.md)
 - [UniformsGameRestObject](docs/UniformsGameRestObject.md)
 - [UniformsGamesRestObject](docs/UniformsGamesRestObject.md)
 - [UniformsTeamRestObject](docs/UniformsTeamRestObject.md)
 - [UniformsTeamsRestObject](docs/UniformsTeamsRestObject.md)
 - [UsedRemainingRestObject](docs/UsedRemainingRestObject.md)
 - [VendorWeatherForecast](docs/VendorWeatherForecast.md)
 - [VendorWeatherForecastRestObject](docs/VendorWeatherForecastRestObject.md)
 - [Venue](docs/Venue.md)
 - [VenueCms](docs/VenueCms.md)
 - [VenueMetadata](docs/VenueMetadata.md)
 - [VenueMetadataRestObject](docs/VenueMetadataRestObject.md)
 - [VenueRestObject](docs/VenueRestObject.md)
 - [VenueTypeEnum](docs/VenueTypeEnum.md)
 - [VenuesRestObject](docs/VenuesRestObject.md)
 - [Video](docs/Video.md)
 - [VideoResolution](docs/VideoResolution.md)
 - [VideoResolutionEnumRestObject](docs/VideoResolutionEnumRestObject.md)
 - [ViolationRestObject](docs/ViolationRestObject.md)
 - [ViolationTypeRestObject](docs/ViolationTypeRestObject.md)
 - [Weather](docs/Weather.md)
 - [WeatherConditionFlagRestObject](docs/WeatherConditionFlagRestObject.md)
 - [WeatherConditionsRestObject](docs/WeatherConditionsRestObject.md)
 - [WeatherContextRestObject](docs/WeatherContextRestObject.md)
 - [WeatherDeviationRestObject](docs/WeatherDeviationRestObject.md)
 - [WeatherDeviationsRestObject](docs/WeatherDeviationsRestObject.md)
 - [WeatherFlyballStandard80RestObject](docs/WeatherFlyballStandard80RestObject.md)
 - [WeatherForecastRestObject](docs/WeatherForecastRestObject.md)
 - [WeatherHitRestObject](docs/WeatherHitRestObject.md)
 - [WeatherHitSegmentActual](docs/WeatherHitSegmentActual.md)
 - [WeatherHitSegmentCalm](docs/WeatherHitSegmentCalm.md)
 - [WeatherHitSegmentRestObject](docs/WeatherHitSegmentRestObject.md)
 - [WeatherHitTrajectoryDataRestObject](docs/WeatherHitTrajectoryDataRestObject.md)
 - [WeatherMetricRestObject](docs/WeatherMetricRestObject.md)
 - [WeatherPitchHandRestObject](docs/WeatherPitchHandRestObject.md)
 - [WeatherPitchRestObject](docs/WeatherPitchRestObject.md)
 - [WeatherPitchSegmentActual](docs/WeatherPitchSegmentActual.md)
 - [WeatherPitchSegmentCalm](docs/WeatherPitchSegmentCalm.md)
 - [WeatherPitchSegmentRestObject](docs/WeatherPitchSegmentRestObject.md)
 - [WeatherPitchTrajectoryDataRestObject](docs/WeatherPitchTrajectoryDataRestObject.md)
 - [WeatherPitchTypeRestObject](docs/WeatherPitchTypeRestObject.md)
 - [WeatherPlayRestObject](docs/WeatherPlayRestObject.md)
 - [WeatherRestObject](docs/WeatherRestObject.md)
 - [WeatherTrajectoryConfidenceTypeRestObject](docs/WeatherTrajectoryConfidenceTypeRestObject.md)
 - [WeatherWindRestObject](docs/WeatherWindRestObject.md)
 - [WeatherWrapperRestObject](docs/WeatherWrapperRestObject.md)
 - [WinLossRecord](docs/WinLossRecord.md)
 - [WinLossRecordRestObject](docs/WinLossRecordRestObject.md)
 - [WindSpeedRestObject](docs/WindSpeedRestObject.md)
 - [XrefId](docs/XrefId.md)
 - [XrefIdRestObject](docs/XrefIdRestObject.md)

## Documentation For Authorization

## basicAuth
- **Type**: HTTP basic authentication

Example
```golang
auth := context.WithValue(context.Background(), sw.ContextBasicAuth, sw.BasicAuth{
	UserName: "username",
	Password: "password",
})
r, err := client.Service.Operation(auth, args)
```
## bearerAuth

## Author


