/*
Copyright © 2024 filifa

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"context"
	"encoding/json"
	"fmt"
	"log"

	"github.com/antihax/optional"
	"github.com/spf13/cobra"
	"scm.dairydemon.net/filifa/mlbstats/api"
)

var date string
var team teamAbbr
var sport = sportAbbr("mlb")

func schedule(cmd *cobra.Command, args []string) {
	var teamIds []int32
	if team != "" {
		teamIds = append(teamIds, int32(teamIDs[string(team)]))
	}

	sportId := int32(sportIDs[string(sport)])

	opts := api.ScheduleApiScheduleOpts{
		TeamId:  optional.NewInterface(teamIds),
		SportId: optional.NewInterface([]int32{sportId}),
		Date:    optional.NewString(date),
	}

	client := api.NewAPIClient(api.NewConfiguration())
	sched, _, err := client.ScheduleApi.Schedule(context.Background(), false, &opts)
	if err != nil {
		log.Fatal(err)
	}

	json, err := json.Marshal(sched)
	if err != nil {
		log.Fatal(err)
	}

	fmt.Println(string(json))
}

// scheduleCmd represents the schedule command
var scheduleCmd = &cobra.Command{
	Use:   "schedule",
	Short: "Fetch daily schedules",
	Long:  `Fetch a day's schedule for the whole league or a specific team.`,
	Args:  cobra.NoArgs,
	Run:   schedule,
}

func init() {
	rootCmd.AddCommand(scheduleCmd)

	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// scheduleCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	scheduleCmd.Flags().VarP(&team, "team", "t", "team to get schedule for")
	scheduleCmd.Flags().StringVarP(&date, "date", "d", "", "date to get schedule for (YYYY-MM-DD)")
	scheduleCmd.Flags().VarP(&sport, "sport", "s", "sport to get schedule for")
}
